@@ -386,10 +386,19 @@ class SchematicGenerator:
         # Check for hierarchical projects: also look for root.kicad_sch
         root_sch_file = self.project_dir / "root.kicad_sch"
 
+        # Debug logging
+        logger.debug(f"🔍 _check_existing_project:")
+        logger.debug(f"   project_dir: {self.project_dir}")
+        logger.debug(f"   project_name: {self.project_name}")
+        logger.debug(f"   Checking .kicad_pro: {kicad_pro_file} -> exists={kicad_pro_file.exists()}")
+        logger.debug(f"   Checking .kicad_sch: {kicad_sch_file} -> exists={kicad_sch_file.exists()}")
+
         # Both files must exist for a valid project
         project_exists = kicad_pro_file.exists()
         schematic_exists = kicad_sch_file.exists() or root_sch_file.exists()
 
+        logger.debug(f"   Result: project_exists={project_exists}, schematic_exists={schematic_exists}")
+
         if project_exists and schematic_exists:
             return True
         elif project_exists or kicad_sch_file.exists() or root_sch_file.exists():
@@ -416,16 +425,24 @@ class SchematicGenerator:
         logger.info("🔄 Updating existing project while preserving your work...")
 
         # Import here to avoid circular dependencies
-        from circuit_synth.kicad.schematic.hierarchical_synchronizer import (
-            HierarchicalSynchronizer,
-        )
-        from circuit_synth.kicad.schematic.sync_adapter import SyncAdapter
+        logger.debug("Importing synchronizers...")
+        try:
+            from circuit_synth.kicad.schematic.hierarchical_synchronizer import (
+                HierarchicalSynchronizer,
+            )
+            from circuit_synth.kicad.schematic.sync_adapter import SyncAdapter
+            logger.debug("   Synchronizers imported successfully")
+        except Exception as e:
+            logger.error(f"   Failed to import synchronizers: {e}")
+            raise
 
         # Load circuit from JSON using the same loader as generate
         logger.debug(f"Loading circuit from {json_file}")
         from .circuit_loader import load_circuit_hierarchy
 
+        logger.debug("Calling load_circuit_hierarchy...")
         top_circuit, sub_dict = load_circuit_hierarchy(json_file)
+        logger.info(f"   Loaded {len(sub_dict)} circuits from JSON")
 
         # For now, we'll use the top circuit for synchronization
         # In the future, this could be extended to handle hierarchical circuits
@@ -434,13 +451,12 @@ class SchematicGenerator:
         project_path = self.project_dir / f"{self.project_name}.kicad_pro"
 
         # Check if this is a hierarchical project
-        has_subcircuits = bool(sub_dict)
+        # Note: sub_dict always includes the main circuit, so check if there's more than one
+        has_subcircuits = len(sub_dict) > 1
+        logger.debug(f"Project has {len(sub_dict)} circuits: {'hierarchical' if has_subcircuits else 'flat'}")
 
         if has_subcircuits:
             # Use hierarchical synchronizer for projects with subcircuits
-            logger.debug(
-                f"Creating hierarchical synchronizer for project: {project_path}"
-            )
             logger.info(
                 f"Detected hierarchical project with {len(sub_dict)} subcircuits"
             )
@@ -451,7 +467,7 @@ class SchematicGenerator:
             logger.info(synchronizer.get_hierarchy_info())
         else:
             # Use regular synchronizer for flat projects
-            logger.debug(f"Creating synchronizer for flat project: {project_path}")
+            logger.debug(f"Creating synchronizer for flat project")
             synchronizer = SyncAdapter(
                 project_path=str(project_path), preserve_user_components=True
             )
@@ -463,6 +479,7 @@ class SchematicGenerator:
             sync_report = synchronizer.sync_with_circuit(top_circuit, sub_dict)
         else:
             sync_report = synchronizer.sync_with_circuit(top_circuit)
+        logger.info("✅ Synchronization completed!")
 
         # Add bounding boxes if requested
         if draw_bounding_boxes:
@@ -622,6 +639,8 @@ class SchematicGenerator:
             schematic_placement: Schematic placement algorithm - "sequential" or "connection_aware" (default: "sequential")
             **pcb_kwargs: Additional keyword arguments passed to PCB generation
         """
+        logger.debug(f"🚀 generate_project() called: force_regenerate={force_regenerate}")
+
         # Check if project already exists
         project_exists = self._check_existing_project()
 
@@ -636,18 +655,25 @@ class SchematicGenerator:
             )
 
             try:
-                return self._update_existing_project(json_file, draw_bounding_boxes)
+                result = self._update_existing_project(json_file, draw_bounding_boxes)
+                return result
             except Exception as e:
+                print(f"🔥 Exception type: {type(e).__name__}")
+                print(f"🔥 Exception message: {e}")
+                import traceback
+                print(f"🔥 Traceback:")
+                traceback.print_exc()
+                print("="*80 + "\n")
                 logger.error(f"❌ Update failed: {e}")
                 logger.error("   Falling back to regeneration...")
                 # Fall through to regeneration
 
         elif project_exists and force_regenerate:
             # User explicitly wants to regenerate
-            logger.warning(
-                f"WARNING: Force regenerating project at: {self.project_dir}"
+            logger.info(
+                f"Force regenerating project at: {self.project_dir}"
             )
-            logger.warning(
+            logger.info(
                 "   This will LOSE all manual work (component positions, wires, etc.)"
             )
 
@@ -728,7 +754,6 @@ class SchematicGenerator:
         logger.info(f"  Main circuit name: {top_name}")
         logger.info(f"  Hierarchical path: {hierarchical_path}")
 
-        print(f"🚨 MAIN_GEN DEBUG: About to create SchematicWriter with draw_bounding_boxes={draw_bounding_boxes}")
         main_writer = SchematicWriter(
             sub_dict[top_name],
             sub_dict,
@@ -740,9 +765,7 @@ class SchematicGenerator:
             draw_bounding_boxes=draw_bounding_boxes,  # Pass bounding box flag
             uuid=root_uuid,  # Pass the root UUID to ensure consistency
         )
-        print(f"🚨 MAIN_GEN DEBUG: SchematicWriter created, calling generate_s_expr()")
         main_sch_expr = main_writer.generate_s_expr()
-        print(f"🚨 MAIN_GEN DEBUG: generate_s_expr() returned")
         sheet_uuids[top_name] = main_writer.uuid_top
         sheet_writers[top_name] = main_writer  # Store main writer for reference
 
@@ -1215,8 +1238,8 @@ class SchematicGenerator:
                     )
 
                 except Exception as e:
-                    logger.warning(f"Could not read existing schematic: {e}")
-                    logger.warning("Will use default placement for all components")
+                    logger.debug(f"Could not read existing schematic: {e}")
+                    logger.debug("Will use default placement for all components")
             else:
                 logger.debug("No existing schematic found - will use default placement")
 
@@ -1302,15 +1325,12 @@ class SchematicGenerator:
                                     pin_net_map[pin.number] = pin.net.name
                                     logger.debug(f"🔍     ✅ Mapped {pin.number} -> {pin.net.name}")
                         elif hasattr(comp, 'pins'):
-                            logger.debug(f"🔍 Using pins list, count: {len(comp.pins)}")
-                            for pin in comp.pins:
-                                logger.debug(f"🔍   Pin: {pin}, has net: {hasattr(pin, 'net')}, has net_name: {hasattr(pin, 'net_name')}")
-                                if hasattr(pin, 'net') and pin.net:
-                                    pin_net_map[pin.number] = pin.net
-                                    logger.debug(f"🔍     ✅ Mapped via net: {pin.number} -> {pin.net}")
-                                elif hasattr(pin, 'net_name') and pin.net_name:
-                                    pin_net_map[pin.number] = pin.net_name
-                                    logger.debug(f"🔍     ✅ Mapped via net_name: {pin.number} -> {pin.net_name}")
+                            # SchematicSymbol from kicad-sch-api: pins don't have net information
+                            # Net connections are stored separately in the schematic's nets list
+                            # For bounding box calculation, we can use an empty pin_net_map
+                            logger.debug(f"🔍 Component has pins list (SchematicSymbol) - skipping net mapping")
+                            logger.debug(f"   (Net info not available on SchematicPin objects from kicad-sch-api)")
+                            # Leave pin_net_map empty - bounding box will be calculated without net labels
 
                         logger.debug(f"🔍 FINAL pin_net_map for {comp.reference}: {pin_net_map}")
                         logger.debug(f"🔍 Calling get_symbol_dimensions with pin_net_map")
@@ -1346,8 +1366,14 @@ class SchematicGenerator:
                         f"Placed new component {comp.reference} at: ({x}, {y})"
                     )
 
-            # Place sheet symbols
-            logger.debug(f"Placing {len(circ.child_instances)} sheet symbols...")
+            # Place sheet symbols at TOP in horizontal row
+            logger.debug(f"Placing {len(circ.child_instances)} sheet symbols at TOP...")
+
+            # Fixed placement: sheets go at top, not using collision manager
+            sheet_top_y = 12.7  # Top margin (0.5 inch)
+            sheet_current_x = 25.4  # Left margin (1 inch)
+            sheet_spacing = 15.0  # Space between sheets
+
             for child in circ.child_instances:
                 # Calculate sheet dimensions based on pin count
                 sub_name = child["sub_name"]
@@ -1356,57 +1382,51 @@ class SchematicGenerator:
                     pin_count = len(sub_circ.nets)
 
                     # Calculate height based on pin count
-                    # Each pin needs 2.54mm (100mil) spacing
                     pin_spacing = 2.54
-                    min_height = 20.32  # Minimum 0.8 inch
-                    padding = 5.08  # 200mil padding top and bottom
+                    min_height = 20.32
+                    padding = 5.08
                     calculated_height = (pin_count * pin_spacing) + (2 * padding)
                     sheet_height = max(min_height, calculated_height)
 
-                    # Calculate width based on sheet name and hierarchical labels
-                    min_width = 25.4  # Minimum 1 inch
-                    char_width = 1.5  # mm per character
-                    name_width = len(sub_name) * char_width + 10  # Add margin
+                    # Calculate width
+                    min_width = 25.4
+                    char_width = 1.5
+                    name_width = len(sub_name) * char_width + 10
 
-                    # Find the longest net name for hierarchical labels
                     max_label_length = 0
                     for net in sub_circ.nets:
                         label_length = len(net.name)
                         if label_length > max_label_length:
                             max_label_length = label_length
 
-                    # Calculate width needed for hierarchical labels
-                    # Labels are placed to the right of the sheet
-                    # Use 1.27mm (50 mils) per character as estimate
                     label_char_width = 1.27
-                    label_width = max_label_length * label_char_width + 10  # Add margin
-
-                    # Sheet width should accommodate both name and labels
-                    # Add extra space for the labels extending beyond the sheet
+                    label_width = max_label_length * label_char_width + 10
                     sheet_width = max(min_width, name_width, min_width + label_width)
 
-                    logger.debug(
-                        f"Sheet {sub_name}: name_width={name_width:.1f}mm, "
-                        f"max_label='{max_label_length}' chars, "
-                        f"label_width={label_width:.1f}mm, "
-                        f"final_width={sheet_width:.1f}mm"
-                    )
-
-                    # Store calculated dimensions
                     child["width"] = sheet_width
                     child["height"] = sheet_height
                 else:
-                    # Use defaults if subcircuit not found
-                    sheet_width = child.get("width", 50.8)  # Default 2 inches
-                    sheet_height = child.get("height", 25.4)  # Default 1 inch
+                    sheet_width = child.get("width", 50.8)
+                    sheet_height = child.get("height", 25.4)
+
+                # FIXED: Place at top with fixed y-coordinate
+                x = sheet_current_x + (sheet_width / 2)
+                y = sheet_top_y + (sheet_height / 2)
+
+                # Snap to grid
+                grid_size = 1.27
+                x = round(x / grid_size) * grid_size
+                y = round(y / grid_size) * grid_size
 
-                x, y = cm.place_symbol(sheet_width, sheet_height)
                 child["x"] = x
                 child["y"] = y
                 logger.debug(
-                    f"Placed sheet {child['sub_name']} ({sheet_width}x{sheet_height}mm) at: ({x}, {y})"
+                    f"Placed sheet {sub_name} at TOP: center=({x:.1f}, {y:.1f}), size={sheet_width:.1f}x{sheet_height:.1f}mm"
                 )
 
+                # Move to next horizontal position
+                sheet_current_x += sheet_width + sheet_spacing
+
             # Determine appropriate paper size based on placement
             self.paper_size = self._determine_paper_size(
                 circ.components, circ.child_instances
