@@ -7,6 +7,7 @@ This ensures proper spacing and collision detection in schematic layouts.
 
 import logging
 import math
+import os
 from typing import Any, Dict, List, Optional, Tuple
 
 logger = logging.getLogger(__name__)
@@ -21,10 +22,11 @@ class SymbolBoundingBoxCalculator:
     DEFAULT_PIN_LENGTH = 2.54  # 100 mils
     DEFAULT_PIN_NAME_OFFSET = 0.508  # 20 mils
     DEFAULT_PIN_NUMBER_SIZE = 1.27  # 50 mils
-    # Increased text width ratio to better match KiCad's actual rendering
-    # KiCad uses proportional fonts where character width varies
+    # Improved text width ratio to match KiCad's proportional font rendering
+    # KiCad uses proportional fonts where average character width is ~0.65x height
+    # This prevents label text from extending beyond calculated bounding boxes
     DEFAULT_PIN_TEXT_WIDTH_RATIO = (
-        1.0  # Width to height ratio for pin text
+        0.65  # Width to height ratio for pin text (proportional font average)
     )
 
     @classmethod
@@ -54,13 +56,11 @@ class SymbolBoundingBoxCalculator:
             raise ValueError("Symbol data is None or empty")
 
         import sys
-        print(f"\n=== CALCULATING BOUNDING BOX ===", file=sys.stderr, flush=True)
-        print(f"include_properties={include_properties}", file=sys.stderr, flush=True)
-        print(f"🎯 pin_net_map received: {pin_net_map}", file=sys.stderr, flush=True)
-        print(f"🎯 pin_net_map type: {type(pin_net_map)}", file=sys.stderr, flush=True)
-        print(f"🎯 pin_net_map is None: {pin_net_map is None}", file=sys.stderr, flush=True)
-        if pin_net_map:
-            print(f"🎯 pin_net_map contents: {dict(pin_net_map)}", file=sys.stderr, flush=True)
+        # Reduced logging frequency - only log if DEBUG environment variable is set
+        debug_enabled = os.getenv("CIRCUIT_SYNTH_DEBUG", "").lower() == "true"
+        if debug_enabled:
+            print(f"\n=== CALCULATING BOUNDING BOX ===", file=sys.stderr, flush=True)
+            print(f"include_properties={include_properties}", file=sys.stderr, flush=True)
 
         min_x = float("inf")
         min_y = float("inf")
@@ -131,18 +131,23 @@ class SymbolBoundingBoxCalculator:
 
         # Include space for component properties (Reference, Value, Footprint)
         if include_properties:
-            # Reference is placed 5mm above center
-            # Value is placed 5mm below center
-            # Footprint is placed 10mm below center
-            # Assume average text width of 10mm for properties
-            property_width = 10.0  # Conservative estimate
+            # Use adaptive spacing based on component dimensions
+            component_width = max_x - min_x
+            component_height = max_y - min_y
+
+            # Adaptive property width: minimum 10mm or 80% of component width
+            property_width = max(10.0, component_width * 0.8)
             property_height = cls.DEFAULT_TEXT_HEIGHT
 
+            # Adaptive vertical spacing: minimum 5mm or 10% of component height
+            vertical_spacing_above = max(5.0, component_height * 0.1)
+            vertical_spacing_below = max(10.0, component_height * 0.15)
+
             # Reference label above
-            min_y -= 5.0 + property_height
+            min_y -= vertical_spacing_above + property_height
 
             # Value and Footprint labels below
-            max_y += 10.0 + property_height
+            max_y += vertical_spacing_below + property_height
 
             # Extend horizontally for property text
             center_x = (min_x + max_x) / 2
@@ -159,198 +164,6 @@ class SymbolBoundingBoxCalculator:
 
         return (min_x, min_y, max_x, max_y)
 
-    @classmethod
-    def calculate_placement_bounding_box(
-        cls,
-        symbol_data: Dict[str, Any],
-    ) -> Tuple[float, float, float, float]:
-        """
-        Calculate bounding box for PLACEMENT purposes - excludes pin labels.
-
-        This method calculates a tighter bounding box that only includes:
-        - Component body (shapes/graphics)
-        - Pin endpoints (without label text)
-        - Small margin for component properties
-
-        Pin label text is excluded because it extends arbitrarily far based on
-        text length and would cause incorrect spacing in text-flow placement.
-
-        Args:
-            symbol_data: Dictionary containing symbol definition from KiCad library
-
-        Returns:
-            Tuple of (min_x, min_y, max_x, max_y) in mm
-
-        Raises:
-            ValueError: If symbol data is invalid or bounding box cannot be calculated
-        """
-        if not symbol_data:
-            raise ValueError("Symbol data is None or empty")
-
-        import sys
-        print(f"\n=== CALCULATING PLACEMENT BOUNDING BOX (NO PIN LABELS) ===", file=sys.stderr, flush=True)
-
-        min_x = float("inf")
-        min_y = float("inf")
-        max_x = float("-inf")
-        max_y = float("-inf")
-
-        # Process main symbol shapes (handle both 'shapes' and 'graphics' keys)
-        shapes = symbol_data.get("shapes", []) or symbol_data.get("graphics", [])
-        print(f"Processing {len(shapes)} main shapes", file=sys.stderr, flush=True)
-        for shape in shapes:
-            shape_bounds = cls._get_shape_bounds(shape)
-            if shape_bounds:
-                s_min_x, s_min_y, s_max_x, s_max_y = shape_bounds
-                min_x = min(min_x, s_min_x)
-                min_y = min(min_y, s_min_y)
-                max_x = max(max_x, s_max_x)
-                max_y = max(max_y, s_max_y)
-
-        # Process pins WITHOUT labels (just pin endpoints)
-        pins = symbol_data.get("pins", [])
-        print(f"Processing {len(pins)} main pins (NO LABELS)", file=sys.stderr, flush=True)
-        for pin in pins:
-            pin_bounds = cls._get_pin_bounds_no_labels(pin)
-            if pin_bounds:
-                p_min_x, p_min_y, p_max_x, p_max_y = pin_bounds
-                min_x = min(min_x, p_min_x)
-                min_y = min(min_y, p_min_y)
-                max_x = max(max_x, p_max_x)
-                max_y = max(max_y, p_max_y)
-
-        # Process sub-symbols
-        sub_symbols = symbol_data.get("sub_symbols", [])
-        for sub in sub_symbols:
-            # Sub-symbols can have their own shapes and pins
-            sub_shapes = sub.get("shapes", []) or sub.get("graphics", [])
-            for shape in sub_shapes:
-                shape_bounds = cls._get_shape_bounds(shape)
-                if shape_bounds:
-                    s_min_x, s_min_y, s_max_x, s_max_y = shape_bounds
-                    min_x = min(min_x, s_min_x)
-                    min_y = min(min_y, s_min_y)
-                    max_x = max(max_x, s_max_x)
-                    max_y = max(max_y, s_max_y)
-
-            sub_pins = sub.get("pins", [])
-            for pin in sub_pins:
-                pin_bounds = cls._get_pin_bounds_no_labels(pin)
-                if pin_bounds:
-                    p_min_x, p_min_y, p_max_x, p_max_y = pin_bounds
-                    min_x = min(min_x, p_min_x)
-                    min_y = min(min_y, p_min_y)
-                    max_x = max(max_x, p_max_x)
-                    max_y = max(max_y, p_max_y)
-
-        # Check if we found any geometry
-        if min_x == float("inf") or max_x == float("-inf"):
-            raise ValueError(f"No valid geometry found in symbol data")
-
-        print(f"After geometry processing: ({min_x:.2f}, {min_y:.2f}) to ({max_x:.2f}, {max_y:.2f})", file=sys.stderr, flush=True)
-        print(f"  Width: {max_x - min_x:.2f}, Height: {max_y - min_y:.2f}", file=sys.stderr, flush=True)
-
-        # Add small margin for visual spacing
-        margin = 0.635  # 25mil margin (reduced from 50mil)
-        min_x -= margin
-        min_y -= margin
-        max_x += margin
-        max_y += margin
-
-        # Add minimal space for component properties (Reference above, Value below)
-        # KiCad places these compactly, so use smaller padding than before
-        property_spacing = 3.0  # Reduced from 5.0mm
-        property_height = 1.27  # Reduced from 2.54mm
-        min_y -= property_spacing + property_height  # Reference above
-        max_y += property_spacing + property_height  # Value below
-
-        print(f"FINAL PLACEMENT BBOX: ({min_x:.2f}, {min_y:.2f}) to ({max_x:.2f}, {max_y:.2f})", file=sys.stderr, flush=True)
-        print(f"  Width: {max_x - min_x:.2f}, Height: {max_y - min_y:.2f}", file=sys.stderr, flush=True)
-        print("=" * 50 + "\n", file=sys.stderr, flush=True)
-
-        return (min_x, min_y, max_x, max_y)
-
-    @classmethod
-    def calculate_visual_bounding_box(
-        cls, symbol_data: Dict[str, Any], pin_net_map: Optional[Dict[str, str]] = None
-    ) -> Tuple[float, float, float, float]:
-        """
-        Calculate bounding box for visual/debug drawing (includes pin labels, no property spacing).
-
-        This shows the actual component geometry including pin labels.
-        Use this for drawing bounding boxes on schematics.
-
-        Args:
-            symbol_data: Dictionary containing symbol definition
-            pin_net_map: Optional mapping of pin numbers to net names (for accurate label sizing)
-
-        Returns:
-            Tuple of (min_x, min_y, max_x, max_y) in mm
-        """
-        # Initialize bounds
-        min_x = float("inf")
-        min_y = float("inf")
-        max_x = float("-inf")
-        max_y = float("-inf")
-
-        # Process main symbol shapes
-        shapes = symbol_data.get("shapes", []) or symbol_data.get("graphics", [])
-        for shape in shapes:
-            shape_bounds = cls._get_shape_bounds(shape)
-            if shape_bounds:
-                s_min_x, s_min_y, s_max_x, s_max_y = shape_bounds
-                min_x = min(min_x, s_min_x)
-                min_y = min(min_y, s_min_y)
-                max_x = max(max_x, s_max_x)
-                max_y = max(max_y, s_max_y)
-
-        # Process pins WITH labels to get accurate visual bounds
-        pins = symbol_data.get("pins", [])
-        for pin in pins:
-            pin_bounds = cls._get_pin_bounds(pin, pin_net_map)
-            if pin_bounds:
-                p_min_x, p_min_y, p_max_x, p_max_y = pin_bounds
-                min_x = min(min_x, p_min_x)
-                min_y = min(min_y, p_min_y)
-                max_x = max(max_x, p_max_x)
-                max_y = max(max_y, p_max_y)
-
-        # Process sub-symbols
-        sub_symbols = symbol_data.get("sub_symbols", [])
-        for sub in sub_symbols:
-            sub_shapes = sub.get("shapes", []) or sub.get("graphics", [])
-            for shape in sub_shapes:
-                shape_bounds = cls._get_shape_bounds(shape)
-                if shape_bounds:
-                    s_min_x, s_min_y, s_max_x, s_max_y = shape_bounds
-                    min_x = min(min_x, s_min_x)
-                    min_y = min(min_y, s_min_y)
-                    max_x = max(max_x, s_max_x)
-                    max_y = max(max_y, s_max_y)
-
-            sub_pins = sub.get("pins", [])
-            for pin in sub_pins:
-                pin_bounds = cls._get_pin_bounds(pin, pin_net_map)
-                if pin_bounds:
-                    p_min_x, p_min_y, p_max_x, p_max_y = pin_bounds
-                    min_x = min(min_x, p_min_x)
-                    min_y = min(min_y, p_min_y)
-                    max_x = max(max_x, p_max_x)
-                    max_y = max(max_y, p_max_y)
-
-        # Check if we found any geometry
-        if min_x == float("inf") or max_x == float("-inf"):
-            raise ValueError(f"No valid geometry found in symbol data")
-
-        # Add only a tiny margin for visibility (no property spacing)
-        margin = 0.254  # 10mil minimal margin
-        min_x -= margin
-        min_y -= margin
-        max_x += margin
-        max_y += margin
-
-        return (min_x, min_y, max_x, max_y)
-
     @classmethod
     def get_symbol_dimensions(
         cls, symbol_data: Dict[str, Any], include_properties: bool = True, pin_net_map: Optional[Dict[str, str]] = None
@@ -503,20 +316,27 @@ class SymbolBoundingBoxCalculator:
             print(f"    label_width={name_width:.2f}, label_height={name_height:.2f} (len={len(label_text)})", file=sys.stderr, flush=True)
 
             # Adjust bounds based on pin orientation
-            # Labels are placed at the PIN ORIGIN and extend AWAY from the component
-            # Pin angle indicates where the pin points (into component), label goes opposite direction
-            if angle == 0:  # Pin points right (into component) - label extends LEFT (away from component)
-                print(f"    Angle 0 (Right pin): min_x {min_x:.2f} -> {x - name_width:.2f}", file=sys.stderr, flush=True)
-                min_x = min(min_x, x - name_width)
-            elif angle == 180:  # Pin points left (into component) - label extends RIGHT (away from component)
-                print(f"    Angle 180 (Left pin): max_x {max_x:.2f} -> {x + name_width:.2f}", file=sys.stderr, flush=True)
-                max_x = max(max_x, x + name_width)
-            elif angle == 90:  # Pin points up (into component) - label extends DOWN (away from component)
-                print(f"    Angle 90 (Up pin): min_y {min_y:.2f} -> {y - name_height:.2f}", file=sys.stderr, flush=True)
-                min_y = min(min_y, y - name_height)
-            elif angle == 270:  # Pin points down (into component) - label extends UP (away from component)
-                print(f"    Angle 270 (Down pin): max_y {max_y:.2f} -> {y + name_height:.2f}", file=sys.stderr, flush=True)
-                max_y = max(max_y, y + name_height)
+            # Labels are placed at PIN ENDPOINT with offset, extending AWAY from the component
+            # Pin angle indicates where the pin points (into component)
+            # Apply KiCad's standard pin name offset (0.508mm / 20 mils)
+            offset = cls.DEFAULT_PIN_NAME_OFFSET
+
+            if angle == 0:  # Pin points right - label extends LEFT from endpoint
+                label_x = end_x - offset - name_width
+                print(f"    Angle 0 (Right pin): min_x {min_x:.2f} -> {label_x:.2f} (offset={offset:.3f})", file=sys.stderr, flush=True)
+                min_x = min(min_x, label_x)
+            elif angle == 180:  # Pin points left - label extends RIGHT from endpoint
+                label_x = end_x + offset + name_width
+                print(f"    Angle 180 (Left pin): max_x {max_x:.2f} -> {label_x:.2f} (offset={offset:.3f})", file=sys.stderr, flush=True)
+                max_x = max(max_x, label_x)
+            elif angle == 90:  # Pin points up - label extends DOWN from endpoint
+                label_y = end_y - offset - name_height
+                print(f"    Angle 90 (Up pin): min_y {min_y:.2f} -> {label_y:.2f} (offset={offset:.3f})", file=sys.stderr, flush=True)
+                min_y = min(min_y, label_y)
+            elif angle == 270:  # Pin points down - label extends UP from endpoint
+                label_y = end_y + offset + name_height
+                print(f"    Angle 270 (Down pin): max_y {max_y:.2f} -> {label_y:.2f} (offset={offset:.3f})", file=sys.stderr, flush=True)
+                max_y = max(max_y, label_y)
 
         # Pin numbers are typically placed near the component body
         if pin_number:
@@ -536,43 +356,3 @@ class SymbolBoundingBoxCalculator:
 
         print(f"    Pin bounds: ({min_x:.2f}, {min_y:.2f}) to ({max_x:.2f}, {max_y:.2f})", file=sys.stderr, flush=True)
         return (min_x, min_y, max_x, max_y)
-
-    @classmethod
-    def _get_pin_bounds_no_labels(
-        cls, pin: Dict[str, Any]
-    ) -> Optional[Tuple[float, float, float, float]]:
-        """Get bounding box for a pin WITHOUT labels - for placement calculations only."""
-        import sys
-
-        # Handle both formats: 'at' array or separate x/y/orientation
-        if "at" in pin:
-            at = pin.get("at", [0, 0])
-            x, y = at[0], at[1]
-            angle = at[2] if len(at) > 2 else 0
-        else:
-            # Handle the format from symbol cache
-            x = pin.get("x", 0)
-            y = pin.get("y", 0)
-            angle = pin.get("orientation", 0)
-
-        length = pin.get("length", cls.DEFAULT_PIN_LENGTH)
-
-        # Calculate pin endpoint based on angle
-        angle_rad = math.radians(angle)
-        end_x = x + length * math.cos(angle_rad)
-        end_y = y + length * math.sin(angle_rad)
-
-        # Only include the pin line itself - NO labels
-        min_x = min(x, end_x)
-        min_y = min(y, end_y)
-        max_x = max(x, end_x)
-        max_y = max(y, end_y)
-
-        # Add small margin for pin graphics (circles, etc)
-        margin = 0.5  # Small margin for pin endpoint graphics
-        min_x -= margin
-        min_y -= margin
-        max_x += margin
-        max_y += margin
-
-        return (min_x, min_y, max_x, max_y)
