@@ -76,8 +76,8 @@ class APISynchronizer:
         # Load schematic
         self.schematic = self._load_schematic()
 
-        # Store the file path in the schematic for instance hierarchy detection
-        self.schematic.file_path = str(self.schematic_path)
+        # NOTE: file_path is already set when the schematic is loaded from file
+        # The Schematic object's file_path property is read-only, so we can't set it
 
         # Initialize API components
         self.component_manager = ComponentManager(self.schematic)
@@ -114,7 +114,23 @@ class APISynchronizer:
         self, schematic: Schematic, base_path: Path, loaded_files: set
     ):
         """Recursively load components from all hierarchical sheets."""
-        for sheet in schematic.sheets:
+        # Check if the schematic has sheets attribute and if it's iterable
+        if not hasattr(schematic, 'sheets') or schematic.sheets is None:
+            logger.debug(f"Schematic has no sheets attribute or it's None - skipping hierarchical loading")
+            return
+
+        # Check if sheets is empty
+        try:
+            sheets_list = list(schematic.sheets) if schematic.sheets else []
+        except (TypeError, AttributeError):
+            logger.debug(f"Schematic.sheets is not iterable - skipping hierarchical loading")
+            return
+
+        if not sheets_list:
+            logger.debug(f"Schematic has no sheets - skipping hierarchical loading")
+            return
+
+        for sheet in sheets_list:
             # Construct the full path to the sheet file
             sheet_path = base_path / sheet.filename
 
@@ -132,19 +148,28 @@ class APISynchronizer:
                 sheet_schematic = ksa.Schematic.load(str(sheet_path))
 
                 # Add all components from the sheet to the main schematic
-                for comp in sheet_schematic.components:
-                    schematic.add_component(comp)
+                if hasattr(sheet_schematic, 'components') and sheet_schematic.components:
+                    for comp in sheet_schematic.components:
+                        schematic.add_component(comp)
 
-                # Add all wires from the sheet
-                for wire in sheet_schematic.wires:
-                    schematic.add_wire(wire)
+                # Add all wires from the sheet (if they exist)
+                if hasattr(sheet_schematic, 'wires') and sheet_schematic.wires:
+                    try:
+                        for wire in sheet_schematic.wires:
+                            schematic.add_wire(wire)
+                    except (TypeError, AttributeError) as e:
+                        logger.debug(f"Could not add wires from sheet: {e}")
 
-                # Add all labels from the sheet
-                for label in sheet_schematic.labels:
-                    schematic.add_label(label)
+                # Add all labels from the sheet (if they exist)
+                if hasattr(sheet_schematic, 'labels') and sheet_schematic.labels:
+                    try:
+                        for label in sheet_schematic.labels:
+                            schematic.add_label(label)
+                    except (TypeError, AttributeError) as e:
+                        logger.debug(f"Could not add labels from sheet: {e}")
 
-                # Recursively load any sub-sheets
-                if sheet_schematic.sheets:
+                # Recursively load any sub-sheets (if they exist)
+                if hasattr(sheet_schematic, 'sheets') and sheet_schematic.sheets:
                     self._load_sheets_recursively(schematic, base_path, loaded_files)
             else:
                 logger.warning(f"Sheet file not found: {sheet_path}")
@@ -205,6 +230,9 @@ class APISynchronizer:
             # Save changes
             self._save_schematic()
 
+            # Print user-friendly synchronization summary
+            self._print_sync_summary(circuit_components, kicad_components, report)
+
             logger.info(
                 f"Synchronization complete: {len(report.matched)} matched, "
                 f"{len(report.added)} added, {len(report.modified)} modified"
@@ -221,6 +249,54 @@ class APISynchronizer:
 
         return report
 
+    def _print_sync_summary(
+        self, circuit_components: Dict, kicad_components: Dict, report: SyncReport
+    ):
+        """Print a user-friendly synchronization summary."""
+        print("\n" + "="*70)
+        print("📋 Synchronization Summary")
+        print("="*70)
+
+        # Components in schematic (KiCad)
+        kicad_refs = sorted(kicad_components.keys()) if kicad_components else []
+        print(f"Components in schematic: {', '.join(kicad_refs) if kicad_refs else '(none)'}")
+
+        # Components in Python code
+        circuit_refs = sorted([comp['reference'] for comp in circuit_components.values()])
+        print(f"Components in Python:    {', '.join(circuit_refs) if circuit_refs else '(none)'}")
+
+        print("\nActions:")
+
+        # Components that were kept (matched)
+        if report.matched:
+            matched_refs = sorted([kicad_ref for _, kicad_ref in report.matched.items()])
+            for ref in matched_refs:
+                print(f"   ✅ Keep: {ref} (matches Python)")
+
+        # Components that were added
+        if report.added:
+            added_refs = sorted(report.added)
+            for ref in added_refs:
+                print(f"   ➕ Add: {ref} (new in Python)")
+
+        # Components that were modified
+        if report.modified:
+            modified_refs = sorted(report.modified)
+            for ref in modified_refs:
+                print(f"   🔧 Update: {ref} (changed in Python)")
+
+        # Components that will be removed (in KiCad but not in Python)
+        matched_kicad_refs = set(report.matched.values())
+        removed_refs = sorted([ref for ref in kicad_refs if ref not in matched_kicad_refs and ref not in report.added])
+        if removed_refs:
+            for ref in removed_refs:
+                print(f"   ⚠️  Remove: {ref} (not in Python code)")
+
+        if not report.matched and not report.added and not report.modified and not removed_refs:
+            print("   (no changes)")
+
+        print("="*70 + "\n")
+
     def _extract_circuit_components(self, circuit) -> Dict[str, Dict[str, Any]]:
         """Extract component information from Circuit Synth circuit."""
         result = {}
@@ -460,7 +536,76 @@ class APISynchronizer:
 
     def _save_schematic(self):
         """Save the modified schematic using kicad-sch-api's native save."""
+        logger.debug("Saving schematic")
+
+        # WORKAROUND: kicad-sch-api bug where WireCollection doesn't sync to _data["wires"]
+        # Manually sync wires from collection to _data before saving
+        self._sync_wires_to_data()
+
         # Use kicad-sch-api's built-in save method which handles all S-expression formatting
         # and lib_symbols automatically. This preserves format and includes wires/labels.
         self.schematic.save(str(self.schematic_path), preserve_format=True)
-        logger.info(f"Saved schematic to {self.schematic_path}")
+        logger.info(f"✅ Schematic saved successfully")
+
+    def _sync_wires_to_data(self):
+        """
+        Sync wires from WireCollection to _data dictionary.
+
+        WORKAROUND for kicad-sch-api bug: The WireCollection maintains wires in memory
+        but doesn't update _data["wires"], so when saving, wires are lost. This method
+        manually syncs the wire collection to _data before saving.
+        """
+        if not hasattr(self.schematic, '_data'):
+            logger.warning("Schematic has no _data attribute")
+            return
+
+        if not hasattr(self.schematic, 'wires'):
+            logger.warning("Schematic has no wires attribute")
+            return
+
+        # Get all wires from the wire collection
+        try:
+            wires_list = list(self.schematic.wires)
+            logger.debug(f"Retrieved {len(wires_list)} wires from collection")
+        except (TypeError, AttributeError) as e:
+            logger.warning(f"Could not access wires collection: {e}")
+            return
+
+        if not wires_list:
+            # No wires to sync
+            logger.debug("No wires to sync (empty list)")
+            return
+
+        logger.debug(f"Syncing {len(wires_list)} wires to _data")
+
+        # Convert Wire objects to dictionaries for _data
+        wire_dicts = []
+        for wire in wires_list:
+            if not hasattr(wire, 'uuid') or not hasattr(wire, 'points'):
+                continue
+
+            # Build wire dictionary matching KiCad S-expression format
+            wire_dict = {
+                "uuid": wire.uuid,
+                "points": []
+            }
+
+            # Add points
+            for point in wire.points:
+                wire_dict["points"].append({
+                    "x": point.x,
+                    "y": point.y
+                })
+
+            # Add stroke info if present
+            if hasattr(wire, 'stroke_width') and wire.stroke_width > 0:
+                wire_dict["stroke"] = {
+                    "width": wire.stroke_width,
+                    "type": "default"
+                }
+
+            wire_dicts.append(wire_dict)
+
+        # Update _data["wires"]
+        self.schematic._data["wires"] = wire_dicts
+        logger.info(f"Synced {len(wire_dicts)} wires to _data")
